@@ -6,7 +6,9 @@ Email: erik.rydow@eng.ox.ac.uk
 from .gaussian_process_emulator import split_training_test_set, train_GP_emulator, predict_GP_emulator, \
     evaluate_GP_emulator, train_and_predict, form_training_set, form_test_set
 
-from .import sensitivity_analysis
+from . import sensitivity_analysis
+
+from . import data_types
 
 __all__ = ["split_training_test_set",
            "train_GP_emulator",
@@ -15,6 +17,6 @@ __all__ = ["split_training_test_set",
            "train_and_predict",
            "form_training_set",
            "form_test_set",
-           "sensitivity_analysis"
-
-]
+           "sensitivity_analysis",
+           "data_types"
+           ]
